@@ -19,10 +19,10 @@ class IsosurfaceCollection(FDSDataCollection):
     def filter_by_quantity(self, quantity: Union[str, Quantity]):
         """Filters all isosurfaces by a specific quantity.
         """
-        if type(quantity) != str:
+        if type(quantity) == Quantity:
             quantity = quantity.name
         return IsosurfaceCollection(x for x in self if
-                                    x.quantity.name.lower() == quantity.lower() or x.name.label.lower() == quantity.lower())
+                                    x.quantity.name.lower() == quantity.lower() or x.quantity.short_name.lower() == quantity.lower())
 
     def __repr__(self):
         return "IsosurfaceCollection(" + super(IsosurfaceCollection, self).__repr__() + ")"
