@@ -4,7 +4,8 @@ from copy import deepcopy
 from typing import Dict, Sequence
 import numpy as np
 
-from fdsreader.utils import Quantity, Mesh
+from fdsreader.fds_classes import Mesh
+from fdsreader.utils import Quantity
 from fdsreader import settings
 import fdsreader.utils.fortran_data as fdtype
 
@@ -61,7 +62,7 @@ class Plot3D(np.lib.mixins.NDArrayOperatorsMixin):
 
     :ivar time: The point in time when this data has been recorded.
     :ivar quantities: List with quantity objects containing information about recorded quantities
-     calculated for this Plot3D with the corresponding label and unit.
+     calculated for this Plot3D with the corresponding short_name and unit.
     """
 
     def __init__(self, root_path: str, time: float, quantities: Sequence[Quantity]):
