@@ -126,7 +126,7 @@ class Smoke3D(np.lib.mixins.NDArrayOperatorsMixin):
         """
         return self._subsmokes[mesh]
 
-    def export_raw_mhd(self, timestep: int, output_dir: str, ordering: Literal['C', 'F'] = 'C'):
+    def export_raw_mhd(self, output_dir: str, ordering: Literal['C', 'F'] = 'C'):
         """Exports the 3d arrays to .raw files with corresponding .mhd meta files.
 
         :param output_dir: The directory in which to save all files.
@@ -135,30 +135,29 @@ class Smoke3D(np.lib.mixins.NDArrayOperatorsMixin):
             filename = "smoke-" + self.quantity.name.lower() + "_mesh-" + mesh.id
             filename = filename.replace(" ", "_")
 
-            data = subsmoke.data[timestep].astype(np.uint8)
+            data = subsmoke.data.astype(np.uint16)
 
-            if ordering == 'F':
-                data = data.T
-
-            data.tofile(os.path.join(output_dir, filename + ".raw"))
+            with open(os.path.join(output_dir, filename + ".raw"), 'wb') as rawfile:
+                for d in data:
+                    if ordering == 'F':
+                        d = d.T
+                    d.tofile(rawfile)
 
             with open(os.path.join(output_dir, filename + ".mhd"), 'w') as metafile:
-                # spacing = [int(round(mesh.coordinates['x'][1] - mesh.coordinates['x'][0], 3)*1000),
-                #            int(round(mesh.coordinates['y'][1] - mesh.coordinates['y'][0], 3)*1000),
-                #            int(round(mesh.coordinates['z'][1] - mesh.coordinates['z'][0], 3)*1000)]
-                spacing = [mesh.coordinates['x'][1] - mesh.coordinates['x'][0],
+                spacing = [self.times[1] - self.times[0],
+                           mesh.coordinates['x'][1] - mesh.coordinates['x'][0],
                            mesh.coordinates['y'][1] - mesh.coordinates['y'][0],
                            mesh.coordinates['z'][1] - mesh.coordinates['z'][0]]
+
                 metafile.writelines(
                     ["ObjectType = Image",
-                     "\nNDims = 3",
+                     "\nNDims = 4",
                      "\nBinaryData = True",
                      "\nBinaryDataByteOrderMSB = False",
-                     f"\nElementSpacing = {spacing[0]:.6} {spacing[1]:.6} {spacing[2]:.6}",
-                     f"\nDimSize = {subsmoke.data.shape[1]} {subsmoke.data.shape[2]} {subsmoke.data.shape[3]}",
-                     "\nElementType = MET_CHAR",
-                     f"\nElementDataFile = {filename + '.raw'}"
-                     "\n[Pixel Data]"])
+                     f"\nElementSpacing = {spacing[0]:.6} {spacing[1]:.6} {spacing[2]:.6} {spacing[3]:.6}",
+                     f"\nDimSize = {subsmoke.data.shape[0]} {subsmoke.data.shape[1]} {subsmoke.data.shape[2]} {subsmoke.data.shape[3]}",
+                     "\nElementType = MET_SHORT",
+                     f"\nElementDataFile = {filename + '.raw'}"])
 
     @property
     def vmax(self):
